@@ -1,6 +1,6 @@
 package App::mojopaste;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 1;
 
@@ -12,7 +12,7 @@ App::mojopaste - Pastebin application
 
 =head1 VERSION
 
-0.25
+0.26
 
 =head1 DESCRIPTION
 
@@ -88,6 +88,9 @@ Don't have cpanm installed?
   $ curl -L http://cpanmin.us | perl - --sudo App::mojopaste
   $ wget http://cpanmin.us -O - | perl - --sudo App::mojopaste
 
+It is also possible to install L<App::mojopaste> using Docker. Check out
+L<https://hub.docker.com/r/jhthorsen/mojopaste> for more information.
+
 =head1 SYNOPSIS
 
 =over 2
